@@ -1,10 +1,11 @@
 from .Image import Image
-from .Meta import PredictMeta, TrainingMeta, EvaluationMeta
+from .Meta import PredictMeta, LivePredictMeta, TrainingMeta, EvaluationMeta
 from .Model import Model, EvaluationModel
 
 __all__ = [
     Image,
     PredictMeta,
+    LivePredictMeta,
     Model,
     EvaluationModel,
     TrainingMeta,
