@@ -1,4 +1,4 @@
-from captur_ml_sdk.dtypes.generics import Image, Meta
+from captur_ml_sdk.dtypes.generics import Image, LivePredictMeta
 
 from pydantic import (
     BaseModel
@@ -15,6 +15,6 @@ class Model(BaseModel):
 
 
 class ModelLivePredictRequest(BaseModel):
-    meta: Optional[Meta] = None
+    meta: Optional[LivePredictMeta] = None
     model: Model
     data: Image
